@@ -37,35 +37,32 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <getopt.h>
-#define __USE_GNU 1
 #include <string.h>
 #include <netdb.h>
 #include <errno.h>
 #include <ctype.h>
 #include <err.h>
-#include <rpcsvc/ypclnt.h>
 
-#define VERSION "3.11"
+#define VERSION "3.22"
 
 enum type_t { DEFAULT, DNS, FQDN, SHORT, ALIAS, IP, NIS, NIS_DEF, ALL_FQDNS, ALL_IPS };
 
 char *progname;
 
 /*
- * Return the name of the nis default domain. This is just a wrapper for
- * yp_get_default_domain.  If something goes wrong, program exits.
+ * Return the name of the nis default domain. Same as localdomain below,
+ * but reports failure for unset domain.
  */
 char *
 localnisdomain()
 {
-	char *buf = 0;
+	/* The historical NIS limit is 1024, the limit on Linux is 64.  */
+	static char buf[1025];
 	int myerror = 0;
 
-	myerror = yp_get_default_domain(&buf);
-
-	/* yp_get_default_domain failed, abort. */
-	if (myerror) {
-		printf("%s: %s\n", progname, yperr_string(myerror));
+	myerror = getdomainname(buf, sizeof buf);
+	if (myerror || strcmp(buf, "(none)") == 0) {
+		printf("%s: Local domain name not set\n", progname);
 		exit (1);
 	}
 
@@ -146,16 +143,16 @@ void
 usage(FILE *stream)
 {
 	fprintf(stream,
-		"Usage: hostname [-v] [-b] {hostname|-F file}         set host name (from file)\n"
-		"       hostname [-v] [-a|-A|-d|-f|-i|-I|-s|-y]       display formatted name\n"
-		"       hostname [-v]                                 display host name\n"
+		"Usage: hostname [-b] {hostname|-F file}         set host name (from file)\n"
+		"       hostname [-a|-A|-d|-f|-i|-I|-s|-y]       display formatted name\n"
+		"       hostname                                 display host name\n"
 		"\n"
-		"       {yp,nis,}domainname [-v] {nisdomain|-F file}  set NIS domain name (from file)\n"
-		"       {yp,nis,}domainname [-v]                      display NIS domain name\n"
+		"       {yp,nis,}domainname {nisdomain|-F file}  set NIS domain name (from file)\n"
+		"       {yp,nis,}domainname                      display NIS domain name\n"
 		"\n"
-		"       dnsdomainname [-v]                            display dns domain name\n"
+		"       dnsdomainname                            display dns domain name\n"
 		"\n"
-		"       hostname -V|--version|-h|--help               print info and exit\n"
+		"       hostname -V|--version|-h|--help          print info and exit\n"
 		"\n"
 		"Program name:\n"
 		"       {yp,nis,}domainname=hostname -y\n"
@@ -279,7 +276,7 @@ show_name(enum type_t type)
 			break;
 		case ALL_IPS:
 		case ALL_FQDNS: {
-			char buf[INET6_ADDRSTRLEN];
+			char buf[255];
 			int flags, ret, family, addrlen;
 
 			/* What kind of information do we want from getnameinfo()? */
@@ -410,7 +407,7 @@ read_file(char *filename, int boot)
 	}
 
 	if (fstat(fileno(fp), &st) == -1
-	   || (buf = (char *) malloc(st.st_size + 1)) == NULL)
+	   || (buf = (char *) calloc(st.st_size + 1, sizeof(char))) == NULL)
 		err(1, NULL);
 
 	while (fgets(buf, st.st_size + 1, fp) != NULL) {
@@ -447,7 +444,6 @@ main(int argc, char **argv)
 		{"long", no_argument, 0, 'f'},
 		{"short", no_argument, 0, 's'},
 		{"version", no_argument, 0, 'V'},
-		{"verbose", no_argument, 0, 'v'},
 		{"alias", no_argument, 0, 'a'},
 		{"ip-address", no_argument, 0, 'i'},
 		{"all-ip-addresses", no_argument, 0, 'I'},
@@ -467,7 +463,7 @@ main(int argc, char **argv)
 	else if (!strcmp(progname, "nisdomainname"))
 		type = NIS_DEF;
 
-	while((o = getopt_long(argc, argv, "aAdfbF:h?iIsVvy", long_options, NULL)) != -1)
+	while((o = getopt_long(argc, argv, "aAdfbF:h?iIsVy", long_options, NULL)) != -1)
 		switch (o) {
 		case 'd':
 			type = DNS;
@@ -499,9 +495,6 @@ main(int argc, char **argv)
 		case 'F':
 			file = optarg;
 			break;
-		case 'v':
-			/* Does not do anything. */
-			break;
 		case 'V':
 			printf("hostname %s\n", VERSION);
 			return 0;
